@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2006 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ class ConfigSection(dict):
         dict.__setattr__(self, "config_obj", config_obj)
         dict.__setattr__(self, "filename", filename)
         dict.__init__(self, *args, **kwargs)
-        
+
     def __getattr__(self, attr):
         if attr in self.keys():
             return self.__getitem__(attr)
@@ -75,28 +75,38 @@ class ConfigSection(dict):
         self.__setitem__(option, val)
         if not self.config_obj.has_section(self.section_name):
             self.config_obj.add_section(self.section_name)
-            
+
         self.config_obj.set(self.section_name, option, val)
         f = file(self.filename, 'w')
         self.config_obj.write(f)
         f.close()
 
-        
+
 class Config(dict):
-    def __init__(self, filename, *args, **kwargs):
+    def __init__(self, filename, error_if_not_found=False, *args, **kwargs):
         dict.__init__(self, *args, **kwargs)
         dict.__setattr__(self, "config_obj", ConfigParser.ConfigParser())
         dict.__setattr__(self, "filename", filename)
-        
+
         try:
             pathmode = os.stat(filename)[stat.ST_MODE]
             if pathmode & 0022 != 0:
                 return
         except (IOError,OSError):
+            if error_if_not_found:
+                log.warn("Config file %s not found or not readable." % filename)
+
             return
-        
+
+        log.debug("Reading config file %s" % filename)
+
         f = file(filename, 'r')
-        self.config_obj.readfp(f)
+        try:
+            self.config_obj.readfp(f)
+        except:
+            log.error("There is an error in the config file: %s" % filename)
+            sys.exit(1)
+
         f.close()
 
         for s in self.config_obj.sections():
@@ -105,7 +115,7 @@ class Config(dict):
                 opts.append((o, self.config_obj.get(s, o)))
 
             self.__setitem__(s, ConfigSection(s, self.config_obj, filename, opts))
-        
+
     def __getattr__(self, sect):
         if sect not in self.keys():
             self.__setitem__(sect, ConfigSection(sect, self.config_obj, self.filename))
@@ -118,8 +128,8 @@ class Config(dict):
 # Config file: directories and ports
 prop.sys_config_file = '/etc/hp/hplip.conf'
 prop.user_config_file = os.path.expanduser('~/.hplip.conf')
-  
-sys_cfg = Config(prop.sys_config_file)
+
+sys_cfg = Config(prop.sys_config_file, True)
 user_cfg = Config(prop.user_config_file)
 
 
@@ -130,7 +140,7 @@ except locale.Error:
     # TODO: Is this the right thing to do?
     log.error("Unable to set locale.")
     locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
-    
+
 try:
     t, prop.encoding = locale.getdefaultlocale()
 except ValueError:
@@ -146,7 +156,7 @@ try:
     prop.hpssd_cfg_port = int(sys_cfg.hpssd.port)
 except ValueError:
     prop.hpssd_cfg_port = 0
-    
+
 prop.version = sys_cfg.hplip.version or 'x.x.x'
 prop.home_dir = sys_cfg.dirs.home or os.path.realpath(os.path.normpath(os.getcwd()))
 prop.run_dir = sys_cfg.dirs.run or '/var/run'
@@ -170,35 +180,35 @@ pdb = pwd.getpwnam(prop.username)
 prop.userhome = pdb[5]
 
 prop.data_dir = os.path.join(prop.home_dir, 'data')
-prop.i18n_dir = os.path.join(prop.home_dir, 'data', 'qm')
 prop.image_dir = os.path.join(prop.home_dir, 'data', 'images')
 prop.xml_dir = os.path.join(prop.home_dir, 'data', 'xml')
+prop.models_dir = os.path.join(prop.home_dir, 'data', 'models')
 
 prop.max_message_len = 8192
 prop.max_message_read = 65536
 prop.read_timeout = 90
 
-prop.ppd_search_path = '/usr/share;/usr/local/share;/usr/lib;/usr/local/lib;/usr/libexec;/opt'
+prop.ppd_search_path = '/usr/share;/usr/local/share;/usr/lib;/usr/local/lib;/usr/libexec;/opt;/usr/lib64'
 prop.ppd_search_pattern = 'HP-*.ppd.*'
 prop.ppd_download_url = 'http://www.linuxprinting.org/ppd-o-matic.cgi'
 prop.ppd_file_suffix = '-hpijs.ppd'
 
-prop.errors_file = os.path.join(prop.home_dir, 'data', 'xml', 'errors.xml')
-prop.strings_file = os.path.join(prop.home_dir, 'data', 'xml', 'strings.xml')
-prop.models_file = os.path.join(prop.home_dir, 'data', 'xml', 'models.xml')
-
 # Spinner, ala Gentoo Portage
 spinner = "\|/-\|/-"
-#spinner = "oOo.oOo."
 spinpos = 0
 
 def update_spinner():
     global spinner, spinpos
-    if sys.stdout.isatty():
+    if log.get_level() != log.LOG_LEVEL_DEBUG and sys.stdout.isatty():
         sys.stdout.write("\b" + spinner[spinpos])
         spinpos=(spinpos + 1) % 8
         sys.stdout.flush()
 
+def cleanup_spinner():
+    if log.get_level() != log.LOG_LEVEL_DEBUG and sys.stdout.isatty():
+        sys.stdout.write("\b \b")
+        sys.stdout.flush()
+
 
 # Internal/messaging errors
 
@@ -244,11 +254,6 @@ ERROR_STRINGS = {
                 ERROR_DEVICEOPEN_FAILED_ONE_DEVICE_ONLY : 'Device open failed - 1 open per session allowed',
                 ERROR_DEVICEOPEN_FAILED_DEV_NODE_MOVED : 'Device open failed - device node moved',
                 ERROR_TEST_EMAIL_FAILED : "Email test failed",
-                #ERROR_SMTP_CONNECT_ERROR : "SMTP server connect error",
-                #ERROR_SMTP_RECIPIENTS_REFUSED : "SMTP recipients refused",
-                #ERROR_SMTP_HELO_ERROR : "SMTP HELO error",
-                #ERROR_SMTP_SENDER_REFUSED : "STMP sender refused",
-                #ERROR_SMTP_DATA_ERROR : "SMTP data error",
                 ERROR_INVALID_HOSTNAME : "Invalid hostname ip address",
                 ERROR_INVALID_PORT_NUMBER : "Invalid JetDirect port number",
                 ERROR_INTERFACE_BUSY : "Interface busy",
@@ -270,11 +275,7 @@ try:
 except NameError:
     True = (1==1)
     False = not True
-    
-# GUI/Console modes
-INTERACTIVE_MODE = 0
-GUI_MODE = 1
-NON_INTERACTIVE_MODE = 2
+
 
 
 
