@@ -1,7 +1,7 @@
 /*****************************************************************************\
   djgenericvip.h : Interface for the generic VIP printer class
 
-  Copyright (c) 2001 - 2002, Hewlett-Packard Co.
+  Copyright (c) 2001 - 2006, Hewlett-Packard Co.
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -59,6 +59,9 @@ public:
     virtual BOOL HagakiFeedDuplexerPresent(BOOL bQueryPrinter);
 #endif
     virtual BOOL GetMargins (PAPER_SIZE ps, float *fMargins);
+#ifdef APDK_LINUX
+    virtual DRIVER_ERROR    SendPerPageHeader (BOOL bLastPage);
+#endif // APDK_LINUX
 
 private:
 	virtual void AdjustModeSettings (BOOL bDoFullBleed, MEDIATYPE ReqMedia,
@@ -90,6 +93,12 @@ public:
     VIPAutoPQMode ();
 }; // VIPAutoPQMode
 
+class VIPCDDVDMode : public PrintMode
+{
+public:
+    VIPCDDVDMode ();
+}; // VIPCDDVDMode
+
 #if defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
 //! DJGenericVIPProxy
 /*!
@@ -136,19 +145,25 @@ public:
 		"Photosmart 380\0"
 		"Photosmart 330\0"
         "Photosmart 420\0"
+        "Photosmart A430\0"
+        "Photosmart A510\0"
 #ifdef APDK_MLC_PRINTER
 		"PSC 1500\0"
 		"PSC 1600\0"
+        "PSC 2100\0"              
+        "PSC 2150\0"
+		"PSC 2170\0"
         "PSC 2200\0"
         "psc 2300\0"
 		"PSC 2350\0"
         "psc 2400\0"
         "psc 2500\0"
-		"Officejet 7400\0"
-		"Officejet 7300\0"
-		"Officejet 7200\0"
-		"Officejet 6200\0"
-        "Officejet 6300\0"
+		"Officejet 74\0"
+		"Officejet 73\0"
+		"Officejet 72\0"
+		"Officejet 62\0"
+        "Officejet 63\0"
+        "Officejet J57\0"
         "Photosmart 2570\0"
 		"Photosmart 2600\0"
 		"Photosmart 2700\0"
@@ -156,6 +171,18 @@ public:
         "Photosmart 3200\0"
         "Photosmart 3300\0"
 #endif
+        "Photosmart A310\0"
+        "Photosmart C31\0"
+        "Photosmart C41\0"
+        "Photosmart C51\0"
+        "Photosmart C61\0"
+        "Photosmart C71\0"
+        "Photosmart Pro B8300\0"
+        "Photosmart D5060\0"
+        "Photosmart D51\0"
+        "Photosmart D61\0"
+        "Photosmart D71\0"
+        "Photosmart D73\0"
     ) {m_iPrinterType = eDJGenericVIP;}
     inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJGenericVIP(pSS); }
 	inline PRINTER_TYPE GetPrinterType() const { return eDJGenericVIP;}
