@@ -40,8 +40,8 @@
 #include "header.h"
 #include "ijs.h"
 #include "ijs_server.h"
-#include "services.h"
 #include "hpijs.h"
+#include "services.h"
 
 #ifdef HAVE_LIBHPIP
 extern  int hpijsFaxServer (int argc, char **argv);
@@ -550,6 +550,13 @@ int main(int argc, char *argv[], char *evenp[])
 
       if (pSS->FirstRaster)
       {
+          char  *pEnv = getenv ("COPY_COUNT");
+          if (pEnv)
+          {
+              i = atoi (pEnv);
+              pSS->pPC->SetCopyCount (i);
+          }
+
          pSS->FirstRaster = 0;
 
          width = (int)(pSS->ph.xres * pSS->pPC->PrintableWidth() + 0.5);
