@@ -44,6 +44,7 @@
 #include "dj3320.h"
 #ifdef APDK_DJ3600
 #include "dj3600.h"
+#include "dj4100.h"
 #endif
 #endif
 #include "dj400.h"
@@ -160,6 +161,7 @@ DJ350Proxy DeviceRegistry::s_DJ350Proxy;
 
 #if defined(APDK_DJ3600) && defined (APDK_DJ3320)
 DJ3600Proxy DeviceRegistry::s_DJ3600Proxy;
+DJ4100Proxy DeviceRegistry::s_DJ4100Proxy;
 #endif
 
 #if defined (APDK_DJ3320)
