@@ -42,10 +42,15 @@
 #include "ijs_server.h"
 #include "hpijs.h"
 #include "services.h"
-#include "hpiom.h"
 
 int UXServices::InitDuplexBuffer()
 {
+    /* Free buffer if new page size in middle of print job. */
+    if (RastersOnPage)
+       delete [] RastersOnPage;
+    if (KRastersOnPage)
+       delete [] KRastersOnPage;
+
     /* Calculate duplex page buffer */
     CurrentRaster = ph.height - 1;  /* Height = physical page in pixels */
     RastersOnPage = (BYTE **) new BYTE[(ph.height) * sizeof (BYTE *)];
@@ -171,17 +176,19 @@ int UXServices::ProcessRaster(char *raster, char *k_raster)
     }
 }
 
+
+#ifdef HAVE_LIBHPIP
+
 /*
  *  Check models.xml for bi-di flag and also check the
  *  device id string for integrity. Some devices return
  *  device id without some expected fields.
  *
  */
-
 BOOL UXServices::CanDoBiDi ()
 {
     char            *hpDev;
-    MsgAttributes   ma;
+    HplipMsgAttributes   ma;
     char            strDevID[512];
 
     // Check for CUPS environment
@@ -197,7 +204,7 @@ BOOL UXServices::CanDoBiDi ()
     {
         return FALSE;
     }
-    hplip_Init ();
+    hplip_Init (&hplip_session);
 
     // Check io-mode in models.xml for this device
 
@@ -206,7 +213,7 @@ BOOL UXServices::CanDoBiDi ()
     {
         return FALSE;
     }
-    if ((hpFD = hplip_OpenHP (hpDev, &ma)) < 0)
+    if ((hpFD = hplip_OpenHP (hplip_session, hpDev, &ma)) < 0)
     {
         return FALSE;
     }
@@ -230,6 +237,15 @@ BOOL UXServices::CanDoBiDi ()
     return TRUE;
 }
 
+#else
+
+BOOL UXServices::CanDoBiDi ()
+{
+    return FALSE;
+}
+
+#endif  // HAVE_LIBHPIP
+
 UXServices::UXServices():SystemServices()
 {
    constructor_error = NO_ERROR;
@@ -270,12 +286,13 @@ UXServices::UXServices():SystemServices()
        }
    }
 
-   Quality = 0;     /* normal */
-   MediaType = 0;   /* plain */
-   ColorMode = 2;   /* color */
+   Quality = QUALITY_NORMAL;
+   MediaType = MEDIA_PLAIN;
+   ColorMode = COLOR;
    PenSet = DUMMY_PEN;
    
    RastersOnPage = 0;
+   KRastersOnPage = 0;
    pPC = NULL;
    pJob = NULL;
    Duplex = 0;
@@ -287,19 +304,29 @@ UXServices::UXServices():SystemServices()
    strcpy(ph.cs, "sRGB");
    VertAlign = -1;
    DisplayStatus = NODISPLAYSTATUS;
+   OutputPath = -1;
 }
 
 UXServices::~UXServices()
 {
    if (RastersOnPage)
       delete [] RastersOnPage;
+   if (KRastersOnPage)
+      delete [] KRastersOnPage;
+#ifdef HAVE_LIBHPIP
    if (hpFD >= 0)
-      hplip_CloseHP(hpFD);  
-   hplip_Exit(); 
+      hplip_CloseHP(hplip_session, hpFD);  
+   hplip_Exit(hplip_session); 
+#endif
 }
 
 DRIVER_ERROR UXServices::ToDevice(const BYTE * pBuffer, DWORD * Count)
 {
+    if (OutputPath == -1)
+    {
+        return IO_ERROR;
+    }
+
    /* Write must be not-buffered, don't use streams */
    if (write(OutputPath, pBuffer, *Count) != (ssize_t)*Count) 
    {
@@ -315,15 +342,19 @@ DRIVER_ERROR UXServices::ToDevice(const BYTE * pBuffer, DWORD * Count)
 
 BOOL UXServices::GetStatusInfo (BYTE * bStatReg)
 {
-   if (hplip_GetStatus(hpFD, (char *)bStatReg, 1) == 1)
+#ifdef HAVE_LIBHPIP
+   if (hplip_GetStatus(hplip_session, hpFD, (char *)bStatReg, 1) == 1)
       return TRUE;
+#endif
    return FALSE;
 }
 
 DRIVER_ERROR UXServices::ReadDeviceID (BYTE * strID, int iSize)
 {
-   if (hplip_GetID(hpFD, (char *)strID, iSize) < 3)
+#ifdef HAVE_LIBHPIP
+   if (hplip_GetID(hplip_session, hpFD, (char *)strID, iSize) < 3)
       return IO_ERROR;
+#endif
    return NO_ERROR;
 }
 
@@ -338,8 +369,10 @@ BOOL UXServices::GetVerticalAlignmentValue(BYTE* cVertAlignVal)
 
 BOOL UXServices::GetVertAlignFromDevice()
 {
-   if ((VertAlign = ReadHPVertAlign(hpFD)) == -1)
+#ifdef HAVE_LIBHPIP
+   if ((VertAlign = ReadHPVertAlign(hplip_session, hpFD)) == -1)
       return FALSE;
+#endif
    return TRUE;
 }
 
@@ -478,6 +511,9 @@ int UXServices::MapPaperSize(float width, float height)
    if (size == CUSTOM_SIZE)
       pPC->SetCustomSize(width, height);
 
+   PaperWidth = pPC->PhysicalPageSizeX ();
+   PaperHeight = pPC->PhysicalPageSizeY ();
+
    if ((r = pPC->SetPaperSize((PAPER_SIZE)size, FullBleed)) != NO_ERROR)
    {
       if (r > 0)
