@@ -25,7 +25,16 @@
 
 \************************************************************************************/
 
-#include "hpaio.h"
+#include <string.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include "hplip_api.h"
+#include "io.h"
+#include "common.h"
+#include "pml.h"
+
+#define DEBUG_DECLARE_ONLY
+#include "sanei_debug.h"
 
 int PmlSetID( PmlObject_t obj, char * oid )
 {
@@ -412,7 +421,7 @@ int PmlReadReply( /*ptalDevice_t dev,*/
                   int request )
 {
     //return ptalChannelRead( dev->pmlChannel, data, maxDatalen );
-  return hplip_ReadHP( deviceid, channelid, (char *)data, maxDatalen, EXCEPTION_TIMEOUT );
+  return hplip_ReadHP(hplip_session, deviceid, channelid, (char *)data, maxDatalen, HPLIP_EXCEPTION_TIMEOUT );
 
     /* TODO: Check for and handle traps. */
 }
@@ -422,8 +431,6 @@ int PmlRequestSet( int deviceid, int channelid, PmlObject_t obj )
     unsigned char data[PML_MAX_DATALEN];
     int datalen=0, status=ERROR, type, result, pml_result;
 
-    DBG( 0,  "PmlRequestSet(obj=0x%8.8X)\n", obj );
-
     PmlSetStatus(obj, PML_ERROR);
                 
     datalen = PmlGetValue(obj, &type, (char *)data, sizeof(data));
@@ -478,8 +485,6 @@ int PmlRequestGet( int deviceid, int channelid, PmlObject_t obj )
     unsigned char data[PML_MAX_DATALEN];
     int datalen=0, stat=ERROR, result, type, pml_result;
 
-    DBG( 0,  "PmlRequestGet(obj=0x%8.8X)\n", obj );
-    
     datalen = GetPml(deviceid, channelid, obj->oid, (char *)data, sizeof(data), &result, &type, &pml_result); 
 
     PmlSetStatus(obj, pml_result);
@@ -497,6 +502,18 @@ int PmlRequestGet( int deviceid, int channelid, PmlObject_t obj )
  * Phase 2 rewrite. des
  */
 
+int is_zero(char *buf, int size)
+{
+   int i;
+
+   for (i=0; i<size; i++)
+   {
+      if (buf[i] != 0)
+         return 0;  /* no */
+   }
+   return 1; /* yes */
+}
+
 /* Unlock Scanner. */
 int clr_scan_token(HPAIO_RECORD *hpaio)
 {
@@ -507,7 +524,7 @@ int clr_scan_token(HPAIO_RECORD *hpaio)
       goto bugout;
    len = PmlGetValue(hpaio->pml.objScanToken, 0, hpaio->pml.scanToken, max);
 
-   if (len != 0)     
+   if (len > 0 && !is_zero(hpaio->pml.scanToken, len))     
    {
       /* Zero token. */
       len = (len > max) ? max : len; 
@@ -520,6 +537,7 @@ int clr_scan_token(HPAIO_RECORD *hpaio)
          goto bugout;
    }
 
+   hpaio->pml.lenScanToken = len;
    stat = OK;
 
 bugout:
@@ -529,18 +547,20 @@ bugout:
 /* Lock Scanner. */
 int set_scan_token(HPAIO_RECORD *hpaio)
 {
-   char token[] = "555";
    int stat=ERROR;
 
    /* Make sure token==0. */
    if (clr_scan_token(hpaio) == ERROR)
       goto bugout;
 
-   if (PmlSetValue(hpaio->pml.objScanToken, PML_TYPE_BINARY, token, sizeof(token)) == ERROR)
-      goto bugout;
-   if (PmlRequestSet(hpaio->deviceid, hpaio->cmd_channelid, hpaio->pml.objScanToken) == ERROR)
-      goto bugout;
-
+   if (hpaio->pml.lenScanToken > 0)
+   {
+      strncpy(hpaio->pml.scanToken, "555", hpaio->pml.lenScanToken);
+      if (PmlSetValue(hpaio->pml.objScanToken, PML_TYPE_BINARY, hpaio->pml.scanToken, hpaio->pml.lenScanToken) == ERROR)
+         goto bugout;
+      if (PmlRequestSet(hpaio->deviceid, hpaio->cmd_channelid, hpaio->pml.objScanToken) == ERROR)
+         goto bugout;
+   }
    stat = OK;
 
 bugout:
@@ -636,6 +656,8 @@ int pml_to_sane_status(HPAIO_RECORD *hpaio)
       goto bugout;
    PmlGetIntegerValue(hpaio->pml.objScannerStatus, 0, &status);
 
+   DBG(6, "PML scannerStatus=%x: %s %d\n", status, __FILE__, __LINE__);
+
    if(status & PML_SCANNER_STATUS_FEEDER_JAM)
    {
       stat = SANE_STATUS_JAMMED;
@@ -646,7 +668,7 @@ int pml_to_sane_status(HPAIO_RECORD *hpaio)
    }
    else if(status & PML_SCANNER_STATUS_FEEDER_EMPTY)
    {
-      if(hpaio->currentBatchScan == SANE_FALSE && hpaio->currentAdfMode == ADF_MODE_AUTO)
+      if(hpaio->currentAdfMode == ADF_MODE_FLATBED || (hpaio->currentBatchScan == SANE_FALSE && hpaio->currentAdfMode == ADF_MODE_AUTO))
       {
          stat = SANE_STATUS_GOOD;
       }
@@ -715,16 +737,22 @@ int pml_start(HPAIO_RECORD *hpaio)
 
    if (hpaio->cmd_channelid < 0)
    {
-      if ((hpaio->cmd_channelid = hplip_OpenChannel(hpaio->deviceid, "HP-MESSAGE")) < 0)
+      if ((hpaio->cmd_channelid = hplip_OpenChannel(hplip_session, hpaio->deviceid, "HP-MESSAGE")) < 0)
+      {
+         bug("failed to open pml channel: %s %d\n", __FILE__, __LINE__);
          goto bugout;
+      }
       SendScanEvent(hpaio->deviceuri, 2000, "event");  /* hpssd message scan started */
    }
    if (!oldStuff)
    {
       if (hpaio->scan_channelid < 0)
       {
-         if ((hpaio->scan_channelid = hplip_OpenChannel(hpaio->deviceid, "HP-SCAN")) < 0)
+         if ((hpaio->scan_channelid = hplip_OpenChannel(hplip_session, hpaio->deviceid, "HP-SCAN")) < 0)
+         {
+            bug("failed to open scan channel: %s %d\n", __FILE__, __LINE__);
             goto bugout;
+         }
       }
    }
 
@@ -742,6 +770,7 @@ int pml_start(HPAIO_RECORD *hpaio)
       goto bugout;
    }
    PmlGetIntegerValue(hpaio->pml.objUploadState, 0, &state);
+   DBG(6, "PML uploadState=%d before scan: %s %d\n", state, __FILE__, __LINE__);
    switch (state)
    {
       case PML_UPLOAD_STATE_IDLE:
@@ -836,7 +865,7 @@ int pml_start(HPAIO_RECORD *hpaio)
    {
       if (hpaio->scan_channelid < 0)
       {
-         if ((hpaio->scan_channelid = hplip_OpenChannel(hpaio->deviceid, "HP-SCAN")) < 0)
+         if ((hpaio->scan_channelid = hplip_OpenChannel(hplip_session, hpaio->deviceid, "HP-SCAN")) < 0)
             goto bugout;
       }
    }
@@ -862,10 +891,22 @@ int pml_start(HPAIO_RECORD *hpaio)
    traits.iBitsPerPixel = letoh16(ps->BlackBitsPerPixel);
    traits.lHorizDPI = letoh16(ps->BlackHorzDPI);
    traits.lVertDPI = letoh16(ps->BlackVertDPI);
-                
+
    /* Set up image-processing pipeline. */
    switch(ps->Code)
    {
+      case MFPDTF_RASTER_MH:
+         pXform->aXformInfo[IP_FAX_FORMAT].dword = IP_FAX_MH;
+         ADD_XFORM( X_FAX_DECODE );
+         break;
+      case MFPDTF_RASTER_MR:
+         pXform->aXformInfo[IP_FAX_FORMAT].dword = IP_FAX_MR;
+         ADD_XFORM( X_FAX_DECODE );
+         break;
+      case MFPDTF_RASTER_MMR:
+         pXform->aXformInfo[IP_FAX_FORMAT].dword = IP_FAX_MMR;   /* possible lineart compression */
+         ADD_XFORM( X_FAX_DECODE );
+         break;
       case MFPDTF_RASTER_BITMAP:
       case MFPDTF_RASTER_GRAYMAP:
       case MFPDTF_RASTER_RGB:
@@ -881,7 +922,7 @@ int pml_start(HPAIO_RECORD *hpaio)
          break;
       default:
          /* Skip processing for unknown encodings. */
-         bug("unknown image encoding sane_start: name=%s sop=%d\n", hpaio->saneDevice.name, ps->Code);
+         bug("unknown image encoding sane_start: name=%s sop=%d %s %d\n", hpaio->saneDevice.name, ps->Code, __FILE__, __LINE__);
    }
 
    index += sizeof(MFPDTF_START_PAGE);
@@ -975,10 +1016,12 @@ int pml_read(HPAIO_RECORD *hpaio, SANE_Byte *data, SANE_Int maxLength, SANE_Int
    int stat=SANE_STATUS_IO_ERROR;
    unsigned int outputAvail=maxLength, outputUsed=0, outputThisPos;
    unsigned char *output = data;
-   unsigned int inputAvail, inputUsed=0, inputNextPos;
+   unsigned int inputAvail=0, inputUsed=0, inputNextPos;
    unsigned char *input;
    int bsize, wResult;
 
+   DBG(8, "sane_hpaio_read called handle=%p data=%p maxLength=%d length=%d: %s %d\n", hpaio, data, maxLength, *pLength, __FILE__, __LINE__);
+
    /* Process any bytes in current record. */
    if (hpaio->RecordIndex < hpaio->RecordSize)
    {
@@ -992,7 +1035,7 @@ int pml_read(HPAIO_RECORD *hpaio, SANE_Byte *data, SANE_Int maxLength, SANE_Int
          bug("ipConvert error=%x: %s %d\n", wResult, __FILE__, __LINE__);
          goto bugout;
       }
-      *pLength += outputUsed;
+      *pLength = outputUsed;
       hpaio->RecordIndex += inputUsed;  /* bump record index */
       if (hpaio->RecordIndex >= hpaio->RecordSize)
          hpaio->BlockIndex += sizeof(MFPDTF_RASTER) + hpaio->RecordSize;  /* bump block index to next record */
@@ -1057,14 +1100,14 @@ int pml_read(HPAIO_RECORD *hpaio, SANE_Byte *data, SANE_Int maxLength, SANE_Int
    else if ((hpaio->page_done || hpaio->pml_done) && !hpaio->ip_done)
    {
       /* No more scan data, flush ipconvert pipeline. */
-      input = 0;
+      input = NULL;
       wResult = ipConvert(hpaio->hJob, inputAvail, input, &inputUsed, &inputNextPos, outputAvail, output, &outputUsed, &outputThisPos);
       if (wResult & (IP_INPUT_ERROR | IP_FATAL_ERROR))
       {
          bug("hpaio: ipConvert error=%x\n", wResult);
          goto bugout;
       }
-      *pLength += outputUsed;
+      *pLength = outputUsed;
       if (outputUsed == 0)
          hpaio->ip_done = 1;
    }
@@ -1080,6 +1123,20 @@ int pml_read(HPAIO_RECORD *hpaio, SANE_Byte *data, SANE_Int maxLength, SANE_Int
       stat = SANE_STATUS_GOOD; /* repeat scan_read */ 
 
  bugout:
+    if (stat != SANE_STATUS_GOOD)
+    {
+       if (hpaio->hJob)
+       {
+          ipClose(hpaio->hJob); 
+          hpaio->hJob = 0;
+       }   
+    }
+
+    //   bug("ipConvert result: inputAvail=%d input=%p inputUsed=%d inputNextPos=%d outputAvail=%d output=%p outputUsed=%d outputThisPos=%d\n", 
+    //                                                 inputAvail, input, inputUsed, inputNextPos, outputAvail, output, outputUsed, outputThisPos);
+
+    DBG(8, "sane_hpaio_read returned output=%p outputUsed=%d length=%d status=%d: %s %d\n", output, outputUsed, *pLength, stat, __FILE__, __LINE__);
+
     return stat;
 }
 
@@ -1107,12 +1164,12 @@ int pml_cancel(HPAIO_RECORD *hpaio)
 
    if (hpaio->scan_channelid >= 0)
    {
-      hplip_CloseChannel(hpaio->deviceid, hpaio->scan_channelid);
+      hplip_CloseChannel(hplip_session, hpaio->deviceid, hpaio->scan_channelid);
       hpaio->scan_channelid = -1;
    }
    if (hpaio->cmd_channelid >= 0)
    {
-      hplip_CloseChannel(hpaio->deviceid, hpaio->cmd_channelid);
+      hplip_CloseChannel(hplip_session, hpaio->deviceid, hpaio->cmd_channelid);
       hpaio->cmd_channelid = -1;
       SendScanEvent(hpaio->deviceuri, 2001, "event");  /* hpssd message scan done */
    }
